Name:           rabbitmq-server
Version:        3.5.3
Release:        %mkrel 1
Summary:        The RabbitMQ message broker
License:        MPL
Group:          Networking/Other
Url:            http://www.rabbitmq.com/
Source0:        http://www.rabbitmq.com/releases/%{name}/v%{version}/%{name}-%{version}.tar.gz
# Original versions from Fedora
Source1:        rabbitmq-server.init
Source2:        rabbitmq-script-wrapper
Source3:        rabbitmq-server.logrotate
Source4:        rabbitmq-server.ocf
Source5:        rabbitmq-server.tmpfiles
Source6:        rabbitmq-server.service
# https://bugzilla.redhat.com/show_bug.cgi?id=998682
# https://bugzilla.redhat.com/show_bug.cgi?id=1032595#c8
Patch0:         rabbitmq-probe-ephemeral-port.patch
BuildArch:      noarch

BuildRequires:  python
BuildRequires:  python-simplejson
BuildRequires:  xmlto
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  docbook-style-xsl
BuildRequires:  erlang
BuildRequires:  erlang-compiler
BuildRequires:  erlang-asn1
BuildRequires:  erlang-eunit
BuildRequires:  erlang-inets
BuildRequires:  erlang-public_key
BuildRequires:  zip
BuildRequires:  netcat

Requires:       erlang
Requires:       erlang-mnesia
Requires:       erlang-os_mon
Requires:       erlang-xmerl
Requires:       erlang-inets
Requires:       erlang-eldap
Requires:       erlang-public_key
Requires:       erlang-ssl
Requires:       erlang-tools
Requires:       logrotate

Requires(post):   systemd >= %{systemd_required_version}
Requires(preun):  systemd >= %{systemd_required_version}
Requires(postun): systemd >= %{systemd_required_version}
Requires(post):   rpm-helper >= 0.24.8-1
Requires(preun):  rpm-helper >= 0.24.8-1

%description
The Advanced Message Queuing Protocol (AMQP) is an application-layer
protocol for messaging. RabbitMQ is its prominent multi-lingual open-source
implementation.


#(fedora) We want to install into /usr/lib, even on 64-bit platforms
%define _rabbit_libdir     %{_exec_prefix}/lib/rabbitmq
%define _rabbit_erllibdir  %{_rabbit_libdir}/lib/rabbitmq_server-%{version}
%define _rabbit_wrapper    %{_builddir}/%{buildsubdir}/`basename %{S:2}`
%define _rabbit_server_ocf %{_builddir}/%{buildsubdir}/`basename %{S:4}`
%define _plugins_state_dir %{_localstatedir}/lib/rabbitmq/plugins
%define _maindir           %{buildroot}%{_rabbit_erllibdir}


%prep
%setup -q
%patch0 -p1

%build
cp %{S:2} %{_rabbit_wrapper}
cp %{S:4} %{_rabbit_server_ocf}
make

%install
%makeinstall_std TARGET_DIR=%{_maindir} \
                 SBIN_DIR=%{buildroot}%{_rabbit_libdir}/bin \
                 MAN_DIR=%{buildroot}%{_mandir} \
                 DOC_INSTALL_DIR=%{buildroot}%{_docdir}/%{name}

mkdir -p %{buildroot}%{_localstatedir}/lib/rabbitmq/mnesia
mkdir -p %{buildroot}%{_localstatedir}/log/rabbitmq

#Copy all necessary lib files etc.
install -p -D -m 0755 %{S:1} %{buildroot}%{_initrddir}/rabbitmq-server
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmqctl
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmq-server
install -p -D -m 0755 %{_rabbit_wrapper} %{buildroot}%{_sbindir}/rabbitmq-plugins
install -p -D -m 0755 %{_rabbit_server_ocf} %{buildroot}%{_exec_prefix}/lib/ocf/resource.d/rabbitmq/rabbitmq-server
install -p -D -m 0644 %{S:3} %{buildroot}%{_sysconfdir}/logrotate.d/rabbitmq-server
install -p -D -m 0644 %{S:6} %{buildroot}%{_unitdir}/%{name}.service

mkdir -p %{buildroot}%{_sysconfdir}/rabbitmq

rm %{_maindir}/LICENSE %{_maindir}/LICENSE-MPL-RabbitMQ %{_maindir}/INSTALL

#Build the list of files
rm -f %{_builddir}/%{buildsubdir}/%{name}.files
echo '%defattr(-,root,root, -)' >> %{_builddir}/%{buildsubdir}/%{name}.files
(cd %{buildroot}; \
    find . -type f ! -regex '\.%{_sysconfdir}.*' \
        ! -regex '\.\(%{_rabbit_erllibdir}\|%{_rabbit_libdir}\).*' \
        | sed -e 's/^\.//' >> %{_builddir}/%{buildsubdir}/%{name}.files)

install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

rm -rf %{buildroot}%{_rabbit_erllibdir}/LICENSE-*

%pre
%_pre_useradd rabbitmq %{_localstatedir}/lib/rabbitmq /bin/bash

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel rabbitmq

#(fedora) Clean out plugin activation state, both on uninstall and upgrade
rm -rf %{_plugins_state_dir}
for ext in rel script boot ; do
    rm -f %{_rabbit_erllibdir}/ebin/rabbit.$ext
done

%files
%doc LICENSE LICENSE-*
%{_sbindir}/rabbitmq-server
%{_sbindir}/rabbitmqctl
%{_sbindir}/rabbitmq-plugins
%{_mandir}/man1/*.xz
%{_mandir}/man5/*.xz
%dir %{_sysconfdir}/rabbitmq
%{_rabbit_erllibdir}
%{_exec_prefix}/lib/ocf/resource.d/rabbitmq/%{name}
%{_rabbit_libdir}/bin
%{_initrddir}/%{name}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/lib/rabbitmq
%attr(0750, rabbitmq, rabbitmq) %dir %{_localstatedir}/log/rabbitmq


%changelog
* Sun May 24 2015 daviddavid <daviddavid> 3.5.3-1.mga4
+ Revision: 822685
- new version: 3.5.3 (fixes CVE-2014-9649 & CVE-2014-9650 & CVE-2015-0862, based on fedora) (mga#15120)
  * Add requires on erlang-eldap (RHBZ#1192089)
  * Add rabbitmq-plugins to default path (#1033305)
  * Fix race in systemd service startup (RHBZ#1059913)
  * Use ephemeral port (32768 and up instead of 10000+) (RHBZ#998682)
  * Do not clobber a file outside the build hierarchy
  * Fix permission for *.service file (rhbz #1001472)
  * Add systemd notify support (RHBZ#1103524), not for now as on Mageia we lack erlang-sd_notify
- add requires on erlang-ssl, erlang-public_key and erlang-tools
- use %%makeinstall_std macro from mageia
- fix License

  + luigiwalser <luigiwalser>
    - rediff upstream patch from 3.4.1 to fix CVE-2014-9649 and CVE-2014-9650

* Sat Oct 19 2013 umeabot <umeabot> 3.1.5-3.mga4
+ Revision: 533411
- Mageia 4 Mass Rebuild

* Thu Aug 29 2013 malo <malo> 3.1.5-2.mga4
+ Revision: 472949
- adding requires erlang-inets (mga#11054)

* Fri Aug 16 2013 malo <malo> 3.1.5-1.mga4
+ Revision: 466928
- update to 3.1.5

* Mon Aug 05 2013 joequant <joequant> 3.1.3-2.mga4
+ Revision: 463964
- rabbit needs some erlang system libs to work.  autodep does not work
  with erlang

* Sun Jun 30 2013 malo <malo> 3.1.3-1.mga4
+ Revision: 448537
- update to 3.1.3

* Sat Jun 22 2013 malo <malo> 3.1.1-1.mga4
+ Revision: 445765
- update to 3.1.1 (Patch from William Murphy)

* Sun Mar 24 2013 colin <colin> 3.0.4-2.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Wed Mar 20 2013 malo <malo> 3.0.4-1.mga3
+ Revision: 404163
- new version 3.0.4

* Tue Feb 05 2013 malo <malo> 3.0.2-1.mga3
+ Revision: 394668
- bug fix version 3.0.2

* Sun Jan 13 2013 umeabot <umeabot> 3.0.1-2.mga3
+ Revision: 380149
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 malo <malo> 3.0.1-1.mga3
+ Revision: 343396
- new version 3.0.1
- new version 2.8.5

  + colin <colin>
    - Switch tmpfiles flags (D->d)
    - Add netcat to buildrequires
    - Do not package tmpfiles conf in /etc
    - Run systemd-tmpfiles --create on post install
    - Don't package the /var/run dir

* Sun Jul 08 2012 malo <malo> 2.8.4-1.mga3
+ Revision: 268785
- update to 2.8.4

* Sat Apr 28 2012 tmb <tmb> 2.7.1-2.mga2
+ Revision: 233843
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sun Feb 19 2012 malo <malo> 2.7.1-1.mga2
+ Revision: 210921
- added back copied files during build
- missing BuildRequires docbook-style-xsl
- missing BuildRequires zip
- fixing an incorrent BuildRequires
- Adding support for systemd.
- imported package rabbitmq-server


* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 08 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.6.1-1
- New Upstream Release - 2.6.1
- Fixed rhbz #738067 (service cannot start - rabbitmq-multi missing)

* Mon Sep 12 2011 Peter Lemenkov <lemenkov@gmail.com> - 2.6.0-1
- New Upstream Release - 2.6.0

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 15 2011 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.2.0-1
- New Upstream Release

* Mon Nov 1 2010 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.1.1-1
- New Upstream Release

* Tue Oct 5 2010 Hubert Plociniczak <hubert.plociniczak@gmail.com> 2.1.0-1
- New Upstream Release
- Added python as a build dependency

* Mon Aug 23 2010 Mike Bridgen <mikeb@rabbitmq.com> 2.0.0-1
- New Upstream Release

* Mon Jun 28 2010 Hubert Plociniczak <hubert@lshift.net> 1.8.0-1
- New Upstream Release
- Backported fix for bug 22871, fixes issues with erlang >= R14A

* Mon Feb 15 2010 Matthew Sackman <matthew@lshift.net> 1.7.2-1
- New Upstream Release

* Fri Jan 22 2010 Matthew Sackman <matthew@lshift.net> 1.7.1-1
- New Upstream Release

* Mon Oct 5 2009 David Wragg <dpw@lshift.net> 1.7.0-1
- New upstream release

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 17 2009 Matthias Radestock <matthias@lshift.net> 1.6.0-1
- New upstream release

* Tue May 26 2009 Hubert Plociniczak <hubert@lshift.net> 1.5.5-2
- Include dist macro in the release number

* Tue May 19 2009 Matthias Radestock <matthias@lshift.net> 1.5.5-1
- Maintenance release for the 1.5.x series

* Mon Apr 6 2009 Matthias Radestock <matthias@lshift.net> 1.5.4-1
- Maintenance release for the 1.5.x series

* Tue Feb 24 2009 Tony Garnock-Jones <tonyg@lshift.net> 1.5.3-1
- Maintenance release for the 1.5.x series

* Mon Feb 23 2009 Tony Garnock-Jones <tonyg@lshift.net> 1.5.2-1
- Maintenance release for the 1.5.x series

* Mon Jan 19 2009 Ben Hood <0x6e6562@gmail.com> 1.5.1-1
- Maintenance release for the 1.5.x series

* Wed Dec 17 2008 Matthias Radestock <matthias@lshift.net> 1.5.0-1
- New upstream release

* Thu Jul 24 2008 Tony Garnock-Jones <tonyg@lshift.net> 1.4.0-1
- New upstream release

* Mon Mar 3 2008 Adrien Pierard <adrian@lshift.net> 1.3.0-1
- New upstream release

* Wed Sep 26 2007 Simon MacMullen <simon@lshift.net> 1.2.0-1
- New upstream release

* Wed Aug 29 2007 Simon MacMullen <simon@lshift.net> 1.1.1-1
- New upstream release

* Mon Jul 30 2007 Simon MacMullen <simon@lshift.net> 1.1.0-1.alpha
- New upstream release

* Tue Jun 12 2007 Hubert Plociniczak <hubert@lshift.net> 1.0.0-1.20070607
- Building from source tarball, added starting script, stopping

* Mon May 21 2007 Hubert Plociniczak <hubert@lshift.net> 1.0.0-1.alpha
- Initial build of server library of RabbitMQ package
